import React, { useState, useCallback, useEffect, node } from 'react';
import ReactDOM from 'react-dom';
import { csv, scaleLinear, scaleTime, max, timeFormat, extent, easeSin } from 'd3';
import { useData } from './useData';
import { AxisBottom } from './AxisBottom';
import { AxisLeft } from './AxisLeft';
import { Marks } from './Marks';
import { BackgroundCircle } from './BackgroundCircle';
import { LinearGradient } from './LinearGradient'

const radius 						= width/96
const width 						= window.innerWidth;
const height 						= window.innerHeight;
const margin 						= { top: height/25, right: width/19.2, bottom: height/6.25, left: width/9.6 };
const xAxisLabelOffset 	= width/16;
const yAxisLabelOffset 	= width/16;


const App = () => {
  const data = useData();

  if (!data) {
    return <pre>Carregando...</pre>
  }

  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;

  const xValue = d => d.data_formatada;
  const xAxisLabel = 'Mês/ano';

  const yValue = d => d.Lucro_Bruto;
  const yAxisLabel = 'Lucro bruto';

  const xAxisTickFormat = timeFormat('%Y-%b');

  const xScale = scaleTime()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();

  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0])
    .nice();
  

  
  //const pathLenght = innerWidth.getTotalLength();
  //console.log(pathLenght)
  
  
  return (
    <svg width={width} height={height}>
      
 			<LinearGradient/>
      
      <g transform={`translate(${margin.left},${margin.top})`}>
        
				<BackgroundCircle 
          xValue={xValue}
          yValue={yValue}
          height={height}/>
        
        <AxisBottom
          xScale={xScale}
          innerHeight={innerHeight}
          tickFormat={xAxisTickFormat}
          tickOffset={width/48}
        />
        <text
          className="axis-label"
          textAnchor="middle"
          transform={`translate(${-yAxisLabelOffset},${innerHeight /
            2}) rotate(-90)`}
        >
          {yAxisLabel}
        </text>
        <AxisLeft yScale={yScale} innerWidth={innerWidth} tickOffset={1} />
        <text
          className="axis-label"
          x={innerWidth / 2}
          y={innerHeight + xAxisLabelOffset}
          textAnchor="middle"
        >
          {xAxisLabel}
        </text>
        <Marks
          data={data}
          xScale={xScale}
          yScale={yScale}
          xValue={xValue}
          yValue={yValue}
          tooltipFormat={xAxisTickFormat}
          circleRadius={width/120}
          stroke-dashoffset= {5}
    			stroke-dasharray = {5}
      		stroke-dashoffset= {0}
        />
      </g>
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);